@@ -3,11 +3,11 @@ use strict;
 use warnings;
 use Carp ();
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 sub new {
     my $class = shift;
-    my %args = (@_ == 1 ? %$_[0] : @_ );
+    my %args = (@_ == 1 ? %{$_[0]} : @_ );
 
     Carp::croak 'tracking_id (tid) missing or invalid'
         unless $args{tid} && $args{tid} =~ /^(?:UA|MO|YT)-\d+-\d+$/;
